Modules
- albums
- comments
- images
- oauth_
flow - OAuth 1.0a three-legged sign-in for SmugMug, used to obtain an access token pair from just the API key and secret. Uses the out-of-band (“oob”) callback: the user approves access in a browser and SmugMug shows a 6-digit verifier code to type back into the CLI.
- upload
Structs
- Auth
User - Who the client is signed in as.
- Node
Tree - Smug
MugClient