pub enum NameCheck {
Upload(String),
Present(NamedImage),
}Expand description
What to call a file in its day’s albums.
Variants
Upload(String)
Upload it under this name (its own, or renamed to avoid a different photo with its name), now reserved for it.
Present(NamedImage)
The same content is already there under this name.