pub struct UploadWorkerContext {
pub client: Arc<SmugMugClient>,
pub album_uri: String,
pub album_key: String,
pub series: Option<Arc<AlbumSeries<ClientAlbumSeries>>>,
pub hash_store: Arc<Mutex<HashStore>>,
pub remote_md5s: Option<Arc<HashMap<String, String>>>,
pub remote_images: Option<Arc<HashMap<String, AlbumImage>>>,
pub dry_run: bool,
pub no_cache: bool,
pub retry_attempts: u32,
pub render_raw: bool,
pub skip_raw_files: Arc<AtomicBool>,
}Fields
client: Arc<SmugMugClient>album_uri: StringTarget album for new images, unless series is set.
album_key: Stringseries: Option<Arc<AlbumSeries<ClientAlbumSeries>>>When set, each new image claims room in this album series instead of
going to album_uri (see album_series).
hash_store: Arc<Mutex<HashStore>>remote_md5s: Option<Arc<HashMap<String, String>>>remote_images: Option<Arc<HashMap<String, AlbumImage>>>Existing images already in the target album, keyed by filename. Used to decide, per file, whether to skip (content unchanged), replace (same filename, different content) or create (new filename).
dry_run: boolno_cache: boolretry_attempts: u32render_raw: boolUpload RAW files as JPEGs rendered from them (see crate::raw)
instead of as originals.
skip_raw_files: Arc<AtomicBool>Auto Trait Implementations
impl !RefUnwindSafe for UploadWorkerContext
impl !UnwindSafe for UploadWorkerContext
impl Freeze for UploadWorkerContext
impl Send for UploadWorkerContext
impl Sync for UploadWorkerContext
impl Unpin for UploadWorkerContext
impl UnsafeUnpin for UploadWorkerContext